@@ -15,7 +15,7 @@ from colorama import init
 import os
 import re
 
-VERSION = "0.4.0"
+VERSION = "0.4.2"
 
 init()
 
@@ -130,14 +130,41 @@ def main():
         chart(colors, data, args, labels)
 
 
-def find_min(list_):
+def find_min(data):
     """Return the minimum value in sublist of list."""
-    return min([min(sublist) for sublist in list_])
+    return min([min(sublist) for sublist in data])
 
 
-def find_max(list_):
+def find_max(data):
     """Return the maximum value in sublist of list."""
-    return max([max(sublist) for sublist in list_])
+    return max([max(sublist) for sublist in data])
+
+
+def normalize(data, width):
+    """Normalize the data and return it."""
+
+    # We offset by the minimum if there's a negative.
+    data_offset = []
+    min_datum = find_min(data)
+    if min_datum < 0:
+        min_datum = abs(min_datum)
+        for datum in data:
+            data_offset.append([d + min_datum for d in datum])
+    else:
+        data_offset = data
+    min_datum = find_min(data_offset)
+    max_datum = find_max(data_offset)
+
+    # max_dat / width is the value for a single tick. norm_factor is the
+    # inverse of this value
+    # If you divide a number to the value of single tick, you will find how
+    # many ticks it does contain basically.
+    norm_factor = width / float(max_datum)
+    normal_data = []
+    for datum in data_offset:
+        normal_data.append([v * norm_factor for v in datum])
+
+    return normal_data
 
 
 def find_max_label_length(labels):
@@ -150,37 +177,6 @@ def find_max_label_length(labels):
     return length
 
 
-def normalize(data, width):
-    """Normalize the data and return it."""
-    min_dat = find_min(data)
-    # We offset by the minimum if there's a negative.
-    off_data = []
-    if min_dat < 0:
-        min_dat = abs(min_dat)
-        for dat in data:
-            off_data.append([_d + min_dat for _d in dat])
-    else:
-        off_data = data
-    min_dat = find_min(off_data)
-    max_dat = find_max(off_data)
-
-    if max_dat < width:
-        # Don't need to normalize if the max value
-        # is less than the width we allow.
-        return off_data
-
-    # max_dat / width is the value for a single tick. norm_factor is the
-    # inverse of this value
-    # If you divide a number to the value of single tick, you will find how
-    # many ticks it does contain basically.
-    norm_factor = width / float(max_dat)
-    normal_dat = []
-    for dat in off_data:
-        normal_dat.append([_v * norm_factor for _v in dat])
-
-    return normal_dat
-
-
 def hist_rows(data, args, colors):
     """Prepare the Histgram graph.
        Each row is printed through the print_row function."""
